from marshmallow import validate,Schema
from marshmallow.fields import Bool, Str, Decimal, Int, Nested, DateTime, Float, List, UUID, Dict

from api_dnl import model
from api_dnl.fields import Choice
from api_dnl.scheme import BaseModelScheme, Emails

from api_dnl.scheme import IP_REGEXP, NAME_REGEXP, PREFIX_REGEXP, TIME_REGEXP, ValidationError, SuccessScheme
from api_dnl.utils.statisticapi2 import FIELD_MAP

# region +++C4ShakenConf+++
class C4ShakenConfScheme(BaseModelScheme):
    id = Int()
    name = Str()
    is_primary = Bool()
    conn_type = Str(validate=[validate.Length(max=3)])
    hostaddr = Str(validate=[validate.Regexp(IP_REGEXP)])
    port = Int()
    heartbeat = Bool()
    heartbeat_interval = Int()

    class Meta:
        model = model.C4ShakenConf
        fields = ('name', 'is_primary', 'conn_type', 'hostaddr', 'port', 'heartbeat', 'heartbeat_interval',)


class C4ShakenConfSchemeGet(C4ShakenConfScheme):
    class Meta:
        model = model.C4ShakenConf
        fields = ('id', 'name', 'is_primary', 'conn_type', 'hostaddr', 'port', 'heartbeat', 'heartbeat_interval',)
        search_fields = (
            'id', 'name', 'is_primary', 'conn_type', 'hostaddr', 'port', 'heartbeat', 'heartbeat_interval',)


class C4ShakenConfSchemeModify(C4ShakenConfScheme):
    pass


# endregion ---C4ShakenConf---
#region +++ShakenAniGroup+++
class ShakenAniGroupScheme(BaseModelScheme):
    id = Int()
    name = Str()
    class Meta:
        model = model.ShakenAniGroup
        fields = ('name',)
class ShakenAniGroupSchemeGet(ShakenAniGroupScheme):
    class Meta:
        model = model.ShakenAniGroup
        fields = ('id','name',)
        search_fields = ('id','name',)
class ShakenAniGroupSchemeModify(ShakenAniGroupScheme):
    pass
#endregion ---ShakenAniGroup---
#region +++ShakenAniGroupList+++
class ShakenAniGroupListScheme(BaseModelScheme):
    id = Int()
    name = Str()
    class Meta:
        model = model.ShakenAniGroupList
        fields = ('name',)
class ShakenAniGroupListSchemeGet(ShakenAniGroupListScheme):
    class Meta:
        model = model.ShakenAniGroupList
        fields = ('id','name',)
        search_fields = ('id','name',)
class ShakenAniGroupListSchemeModify(ShakenAniGroupListScheme):
    pass
#endregion ---ShakenAniGroupList---
#region +++ShakenAniGroupListRel+++
class ShakenAniGroupListRelScheme(BaseModelScheme):
    ani_group_list_id = Int()
    ani_group_id = Int()
    attest_lvl = Str(validate=[validate.Length(max=1)])
    class Meta:
        model = model.ShakenAniGroupListRel
        fields = ('ani_group_list_id','ani_group_id','attest_lvl',)
class ShakenAniGroupListRelSchemeGet(ShakenAniGroupListRelScheme):
    class Meta:
        model = model.ShakenAniGroupListRel
        fields = ('ani_group_list_id','ani_group_id','attest_lvl',)
        search_fields = ('ani_group_list_id','ani_group_id','attest_lvl',)
class ShakenAniGroupListRelSchemeModify(ShakenAniGroupListRelScheme):
    pass
#endregion ---ShakenAniGroupListRel---
#region +++ShakenAniGroupRel+++
class ShakenAniGroupRelScheme(BaseModelScheme):
    group_id = Int()
    did = Str(validate=[validate.Length(max=16)])
    created_on = DateTime()
    class Meta:
        model = model.ShakenAniGroupRel
        fields = ('group_id','did')
class ShakenAniGroupRelSchemeGet(ShakenAniGroupRelScheme):
    class Meta:
        model = model.ShakenAniGroupRel
        fields = ('group_id','did','created_on',)
        search_fields = ('group_id','did',)
        query_fields=('created_on_gt','created_on_lt',)
class ShakenAniGroupRelSchemeModify(ShakenAniGroupRelScheme):
    pass
#endregion ---ShakenAniGroupRel---